<?php

if(!defined('ABSPATH')) die('-1');

class AwesomeLiveChat_Metabox extends AwesomeLiveChat
{
    /**
     * Boots object
     *
     * @since  1.0.0
     * @access private
     * @var object
     */
    private $Boots;

    /**
     * Settings/Options
     *
     * @since  1.0.0
     * @access private
     * @var array
     */
    private $Options;

    /**
     * Library
     *
     * @since  1.0.0
     * @access private
     * @var object
     */
    private $_;

    /**
     * Boots Metabox Extension
     *
     * @since  1.0.0
     * @access private
     * @var object
     */
    private $Metabox;

    /**
     * Get the Boots framework object.
     * Get the plugin settings.
     * Get the plugin library.
     *
     * @since  1.0.0
     * @uses   AwesomeLiveChat::boots()
     *         return boots object
     * @uses   AwesomeLiveChat::options()
     *         return options
     * @uses   AwesomeLiveChat_Library
     *         plugin library/helper
     * @access public
     * @param  void
     * @return void
     */
    public function __construct()
    {
        $this->Boots    = $this->boots();
        $this->Options  = $this->options();
        $this->_        = new AwesomeLiveChat_Library();
        $this->Metabox  = $this->Boots->Metabox;

        add_action('add_meta_boxes', array($this, 'meta'));
    }

    public function meta()
    {
        global $post;
        $id = $post->ID;

        $Posttypes = get_post_types(array(
            'public' => true,
            '_builtin' => false
        ));
        $Posttypes[] = 'post';
        $Posttypes[] = 'page';

        $saved = $this->Boots->Database
            ->term('_alc_show')
            ->get($id);

        if($saved) $value = $saved;
        else
        {
            $Placement = $this->_->settings('general', 'placement');
            $Screen = get_current_screen();
            $value = in_array($Screen->post_type, $Placement)
                ? 'yes'
                : 'no';
        }

        $this->Metabox->create('alc_metabox', 'Awesome Live Chat')
        ->in($Posttypes)
        ->context('side')
        ->priority('high')
        ->add('select', array(
            'title' => __('Show Chat', 'awesome-live-chat'),
            'name'  => '_alc_show',
            'data'  => array(
                'yes'  => __('Yes', 'awesome-live-chat'),
                'no'   => __('No', 'awesome-live-chat')
            ), 'value' => $value
        ))->done();
    }
}
new AwesomeLiveChat_Metabox();